Coverage report

# Coverage report: 31%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 564 | 390 | 0 | 31%
/home/lvcong/PythonProjects/sanic-restful/sanic_restful/__init__.py | 4 | 0 | 0 | 100%
/home/lvcong/PythonProjects/sanic-restful/sanic_restful/__version__.py | 1 | 1 | 0 | 0%
/home/lvcong/PythonProjects/sanic-restful/sanic_restful/api.py | 97 | 75 | 0 | 23%
/home/lvcong/PythonProjects/sanic-restful/sanic_restful/exceptions.py | 7 | 0 | 0 | 100%
/home/lvcong/PythonProjects/sanic-restful/sanic_restful/fields.py | 148 | 48 | 0 | 68%
/home/lvcong/PythonProjects/sanic-restful/sanic_restful/json.py | 12 | 6 | 0 | 50%
/home/lvcong/PythonProjects/sanic-restful/sanic_restful/marshal.py | 40 | 22 | 0 | 45%
/home/lvcong/PythonProjects/sanic-restful/sanic_restful/reqparse.py | 170 | 170 | 0 | 0%
/home/lvcong/PythonProjects/sanic-restful/sanic_restful/resource.py | 48 | 37 | 0 | 23%
/home/lvcong/PythonProjects/sanic-restful/sanic_restful/util.py | 37 | 31 | 0 | 16%

No items found using the specified filter.